==> openGion7.2.6.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA09S.sql <==
/****************************************************************************/
/* GEA09 ( ﾕｰｻﾞｰｱｸｾｽ画面管理ﾃｰﾌﾞﾙ )                                         */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GEA09 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , USERID       varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID      */
 , GUIKEY       varchar           (   30 )                  NOT NULL            /*  30 画面ID       */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  40 表示順       */
 , NAME_JA      varchar           (  200 )                                      /*  50 名称         */
 , LAST_ACCESS  varchar           (   14 )                                      /*  60 最終ｱｸｾｽ時間 */
 , FGFAVORITE   varchar           (    1 )                                      /*  70 お気に入り   */
 , CLASSIFY     varchar           (  120 )                                      /*  80 分類         */
 , NEXTGUI      varchar           ( 1000 )                                      /*  90 次画面ﾘｽﾄ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA09S.sql <==
/****************************************************************************/
/* GEA09 ( ｱｸｾｽ管理ﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GEA09 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , USERID       varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID      */
 , GUIKEY       varchar           (   30 )                  NOT NULL            /*  30 画面ID       */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  40 表示順       */
 , NAME_JA      varchar           (  200 )                                      /*  50 名称         */
 , LAST_ACCESS  varchar           (   14 )                                      /*  60 最終ｱｸｾｽ時間 */
 , FGFAVORITE   varchar           (    1 )                                      /*  70 お気に入り   */
 , CLASSIFY     varchar           (  120 )                                      /*  80 分類         */
 , NEXTGUI      varchar           ( 1000 )                                      /*  90 次画面ﾘｽﾄ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
